@@ -6,7 +6,7 @@
 """
 from __future__ import absolute_import
 
+from . import cuahsi
 from . import ncdc
 from . import usgs
 from . import util
-from . import wof
